From 6852ccd8de66d7cf647f609b437aa87c9a9545c8 Mon Sep 17 00:00:00 2001
From: Malte Franken <exxamalte@users.noreply.github.com>
Date: Fri, 28 Feb 2020 21:41:21 +1000
Subject: [PATCH] change log level (#32244)

---
 homeassistant/components/feedreader/__init__.py | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/homeassistant/components/feedreader/__init__.py b/homeassistant/components/feedreader/__init__.py
index 2643607c3a8..548654c11c0 100644
--- a/homeassistant/components/feedreader/__init__.py
+++ b/homeassistant/components/feedreader/__init__.py
@@ -102,11 +102,13 @@ class FeedManager:
             # during the initial parsing of the XML, but it doesn't indicate
             # whether this is an unrecoverable error. In this case the
             # feedparser lib is trying a less strict parsing approach.
             # If an error is detected here, log error message but continue
             # processing the feed entries if present.
             if self._feed.bozo != 0:
-                _LOGGER.error(
-                    "Error parsing feed %s: %s", self._url, self._feed.bozo_exception
+                _LOGGER.warning(
+                    "Possible issue parsing feed %s: %s",
+                    self._url,
+                    self._feed.bozo_exception,
                 )
             # Using etag and modified, if there's no new data available,
             # the entries list will be empty
@@ -102,11 +102,13 @@ class FeedManager:
             # whether this is an unrecoverable error. In this case the
             # feedparser lib is trying a less strict parsing approach.
-            # If an error is detected here, log error message but continue
+            # If an error is detected here, log warning message but continue
             # processing the feed entries if present.
             if self._feed.bozo != 0: